@@ -1,3 +1,8 @@
+@c -*-texinfo-*-
+@c This is part of the GNU edition of V.E.R.A.
+@c Copyright (C) 1993/2001 Oliver Heidelbach
+@c See the file vera.texi for copying conditions.
+@c 
 @c Syntax:
 @c ACRONYM
 @c Expansion[ (Reference)][, "Style"]
@@ -326,7 +331,7 @@ Carbon Copy
 Continuity Cell (ATM)
 
 @item CC
-Country Code (MS-ISDN, GSM)
+Country Code (MS-ISDN, GSM, Mobile-Systems)
 
 @item CC
 Cross Connector
@@ -347,7 +352,7 @@ Cube Connected Cycles (MP)
 Campus Computer Communication Association (org., USA)
 
 @item CCCH
-Common Control CHannel (GSM)
+Common Control CHannel (GSM, Mobile-Systems)
 
 @item CCCI
 Center for Cyber Communities Initiative (org., Japan)
@@ -380,7 +385,7 @@ Connection Control Function (IN)
 Controller Configuration Facility
 
 @item CCFL
-Cold Cathode Fluorescent Lamp
+Cold Cathode Fluorescent Lamp (LCD)
 
 @item CCFT
 Cold Cathode Fluorescent Tube (LCD, Display)
@@ -442,6 +447,9 @@ Common Communications Support (IBM, SAA)
 @item CCS
 Communications-Computer Systems, "C-CS"
 
+@item CCS
+Cyprus Computer Society (Org, Zypern)
+
 @item CCS7
 Common Channel signaling System 7 (IN, Telekom, CCITT)
 
@@ -514,6 +522,9 @@ Compact Disk - Digital Audio (CD, digital audio), "CD-DA"
 @item CDDI
 Copper Distributed Data Interface (FDDI, UTP)
 
+@item CDE
+Certified Directory Engineer (Novell, Netware)
+
 @item CDE
 Common Desktop Environment
 
@@ -548,7 +559,7 @@ Control Development Toolkit (MS, VB)
 Compressed Data Mode
 
 @item CDMA
-Code Division Multiple Access (DFUE)
+Code Division Multiple Access (DFUe)
 
 @item CDMIDI
 Compact Disk + Musical Instruments Digital Interface (CD, MIDI), "CD+MIDI" 
@@ -566,7 +577,7 @@ Collaboration Data Objects (WSH, MS)
 Cellular Digital Packet Data
 
 @item CDPD
-Cellular Digital Packet Data (Mobile Systems)
+Cellular Digital Packet Data (Mobile-Systems)
 
 @item CDR
 Compact Disk - Recordable (CD), "CD-R" 
@@ -581,10 +592,10 @@ Cached Dynamic Random Access Memory (RAM, DRAM, IC)
 Cross DOMAIN Resource Manager (VTAM, SSCP, IBM)
 
 @item CDROM
-Compact Disk - Read Only Memory (CD), "CD-ROM" 
+Compact Disk - Read Only Memory (CD, ROM), "CD-ROM" 
 
 @item CDROMXA
-Compact Disk - ROM / eXtended Architecture (CD, MPC), "CD-ROM/XA" 
+Compact Disk - ROM / eXtended Architecture (CD, MPC, ROM), "CD-ROM/XA" 
 
 @item CDRW
 Compact Disk - ReWritable (CD), "CD-RW"
@@ -863,7 +874,7 @@ Classless Internet DOMAIN Routing [protocol] (RFC 1519)
 Commission Internationale de l'Eclairage (org.)
 
 @item CIFS
-Common Internet File System
+Common Internet File System (TCP/IP)
 
 @item CIL
 Computer Integration Laboratories (org., Apple, IBM, Novell, Sun, ...)
@@ -871,6 +882,9 @@ Computer Integration Laboratories (org., Apple, IBM, Novell, Sun, ...)
 @item CILABS
 Component Integration LABoratorieS (org.,, OpenDoc, Apple, IBM, Adobe, ...), CILabs
 
+@item CIM
+Cisco Interactive Mentor (Cisco)
+
 @item CIM
 Computer Integrated Manufacturing
 
@@ -934,12 +948,18 @@ Computer Intergrated Tooling
 @item CITED
 Copyright In Transmitted Electronic Documents (ESPRIT)
 
+@item CIU
+??? [switch] (IBM)
+
 @item CIVIC
 Cyclone Integrated Video Interfaces Controller (Apple)
 
 @item CIX
 Commercial Internet eXchange (ISP)
 
+@item CL
+Column Address Strobe Latency (CAS)
+
 @item CL
 ConnectionLess (CO)
 
@@ -1022,7 +1042,7 @@ Configuration Management
 Configuration Manager (BIOS, PNP)
 
 @item CM
-Connection Management (RR, MM, GSM)
+Connection Management (RR, MM, GSM, Mobile-Systems)
 
 @item CM2
 Communication Manager /2 (IBM), "CM/2"
@@ -1042,6 +1062,9 @@ Computer Mediated Communications [studies centre] (org., USA)
 @item CME
 Component Management Entity
 
+@item CMGA
+Community of Massive Gaming Agents Internet, Germany, Telekom
+
 @item CMGS
 Cyan Magenta Gelb Schwarz (color system, DTP)
 
@@ -1084,12 +1107,18 @@ Cooperative Marketing Partner (DEC)
 @item CMR
 Cell Misinsertion Rate (ATM)
 
+@item CMS
+Chip Multiprocessor System
+
 @item CMS
 Code Management System (DEC, CM)
 
 @item CMS
 Color Management System
 
+@item CMS
+Content Management System
+
 @item CMS
 Conversational Monitor System (IBM, VME)
 
@@ -1109,7 +1138,7 @@ Cyan Magenta Yellow blacK (color system, DTP)
 Communications Network
 
 @item CN
-Connection Management (Mobile Systems)
+Connection Management (Mobile-Systems)
 
 @item CN
 Coordination Message (ISO 9646-3, TTCN)
@@ -1120,6 +1149,9 @@ Copy Network
 @item CN
 Corporate Network
 
+@item CNA
+Certified Novell Administrator (Novell, Netware)
+
 @item CNA
 Communication Network Architecture (SEL)
 
@@ -1171,12 +1203,21 @@ Communications Network for Manufacturing Applications
 @item CNMS
 Cylink Network Management System
 
+@item CNNIC
+China interNet Network Information Center (org., Internet, China)
+
 @item CNP
 Corporate Network Products (TPS)
 
+@item CNR
+Communications and Network Riser
+
 @item CNRCVUUCP
 Compressed News ReCeive Via UUCP
 
+@item CNS
+Certified Novell Salesperson (Novell, Netware)
+
 @item CNS
 Complimentary Network Service
 
@@ -1189,6 +1230,9 @@ Check Out (RCS)
 @item CO
 Connection Oriented (CL)
 
+@item COAS
+Caldera Open Administration System (Linux)
+
 @item COAST
 Cache On A STick (Intel)
 
@@ -1204,6 +1248,9 @@ COmmon Business Orientated Language
 @item COBRA
 COmmunication technology: Basic Research and Applications
 
+@item COBWEB
+COntent-Based image retrieval on the WEB (WWW, ESPRIT)
+
 @item COCA
 Cost Of Cracking Adjustment (cryptography)
 
@@ -1411,6 +1458,9 @@ Combined Programming Language (DEC, PL/1)
 @item CPL
 Conversational Programming Language (DEC)
 
+@item CPLD
+Complex Programmable Logic Device (PLD, IC, RL)
+
 @item CPM
 Control Program for Microcomputers (OS), "CP/M"
 
@@ -1519,6 +1569,9 @@ Compile-time Reconfigurable Logic (RL)
 @item CRLF
 Carriage Return - Line Feed (ASCII, DOS)
 
+@item CRM
+Customer Relationship Management
+
 @item CRP
 Common Reference Platform (PowerPC)
 
@@ -1549,6 +1602,9 @@ Client/Server, "C/S"
 @item CS
 Code Segment [register] (CPU, Intel, assembler)
 
+@item CS
+Coding Scheme (GPRS, Mobile-Systems)
+
 @item CS
 Computer Science
 
@@ -1636,6 +1692,9 @@ CompuServe Incorporated (ISP)
 @item CSI
 Convergence Sublayer Indication (ATM)
 
+@item CSIC
+Customer Specific Integrated Circuit (IC, RL)
+
 @item CSID
 Caller Station IDentification (Fax)
 
@@ -1651,6 +1710,9 @@ Commonwealth Scientific and Industrial Research Organization (org., UK)
 @item CSIS
 Central Schengen Information Systen (SIS, Europe, Strasbourg)
 
+@item CSKI
+Ceska Spolecnost pro Kybernetiku a Informatiku (org., Tschechien)
+
 @item CSL
 Computer SoLutions [software gmbh] (Haendler)
 
@@ -1792,6 +1854,9 @@ Command TERMinal (DEC)
 @item CTI
 Computer Telephony Integration
 
+@item CTM
+Communication Trunk of Medium range Mil., Germany
+
 @item CTR
 [columbia university] Center for Telecommunications Research (org., USA)
 
@@ -1871,7 +1936,7 @@ Computer Vision Syndrome
 Concurrent Versions System (Unix)
 
 @item CVSD
-Continuous Variable Delta Modulation (DFUE)
+Continuous Variable Delta Modulation (DFUe)
 
 @item CVSELP
 Codex Vector Sum Excited Linear Prediction [algorithm] (Motorola, VOFR)
@@ -1882,6 +1947,9 @@ Centrum voor Wiskunde en Informatica (org., Netherlands)
 @item CWIS
 Campus Wide Information System
 
+@item CWMI
+Common Warehousing Metadata Interchange (DB, DWH)
+
 @item CWP
 Current Workspace Pointer (SPARC, CPU)
 
