@@ -1,3 +1,8 @@
+@c -*-texinfo-*-
+@c This is part of the GNU edition of V.E.R.A.
+@c Copyright (C) 1993/2001 Oliver Heidelbach
+@c See the file vera.texi for copying conditions.
+@c 
 @c Syntax:
 @c ACRONYM
 @c Expansion[ (Reference)][, "Style"]
@@ -20,10 +25,10 @@ Flow Admission Acknowledge [message] (LFAP)
 Fast Access Btree Structure
 
 @item FAC
-Final Assembly Code (IMEI, GSM)
+Final Assembly Code (IMEI, GSM, Mobile-Systems)
 
 @item FACCH
-Fast Associated Control CHannel (GSM, DCCH)
+Fast Associated Control CHannel (GSM, DCCH, Mobile-Systems)
 
 @item FACE
 Framed Access Command Environment (Unix, SVR4)
@@ -143,10 +148,10 @@ File Control BlockS (DOS)
 Federal Communications Commission (org., USA)
 
 @item FCC
-Forward Carbon Copy (DFUE)
+Forward Carbon Copy (DFUe)
 
 @item FCCH
-Frequency Correction CHannel (GSM)
+Frequency Correction CHannel (GSM, Mobile-Systems)
 
 @item FCCN
 Fundacao para a Computacao Cientifica Nacional (org., Portugal)
@@ -223,11 +228,14 @@ Full Duplex EtherSwitch (Kalpana)
 @item FDL
 File Definition Language
 
+@item FDL
+Free Documentation License (GNU)
+
 @item FDM
 Frequency Division Multiplexing (FDM)
 
 @item FDMA
-Frequency Division Multiple Access (Mobile Systems)
+Frequency Division Multiple Access (Mobile-Systems)
 
 @item FDO
 Functional Device Object
@@ -257,7 +265,7 @@ Fast Data Enciphering Algorithm (cryptography)
 Far End Block Error (SONET)
 
 @item FEC
-Forward Error Correction (GSM)
+Forward Error Correction (GSM, Mobile-Systems)
 
 @item FECN
 Forward Explicit Congestion Notification (ATM)
@@ -287,7 +295,7 @@ Forward Error Correction (satellite)
 Far End Receive Failure (UNI, ATM, SONET, OAM)
 
 @item FESI
-Federacion Espanola de Sociedades de Informatica (org.)
+Federacion Espanola de Sociedades de Informatica (org., Spain)
 
 @item FET
 Field Effect Transistor
@@ -376,6 +384,9 @@ Forth Interest Group (org., Forth)
 @item FIGLET
 Frank, Ian and Glenn's LETters (ASCII, fonts)
 
+@item FILE
+Free Internet Lexicon and Encyclopedia (WWW, DICT)
+
 @item FILO
 First In Last Out
 
@@ -484,6 +495,9 @@ Flash Memory Manager (Intel)
 @item FMS
 FernMeldeSystem
 
+@item FMTEYEWTK
+Far More Than Everything You Ever Wanted To Know (slang, PERL)
+
 @item FNC
 Federal Networking Council (org., USA)
 
@@ -577,6 +591,9 @@ Fast Packet Adaption (FPS, FPR)
 @item FPA
 Floating Point Accelerator
 
+@item FPAA
+Field Programmable ALU Array (IC, ALU, RL)
+
 @item FPC
 Floating Point Coprocessor
 
@@ -590,7 +607,7 @@ FTAM Protocol Data Unit (PDU)
 Floating Point Engine
 
 @item FPGA
-Field Programmable Gate Array
+Field Programmable Gate Array (RL)
 
 @item FPI
 Flux Changes per Inch (HDD)
@@ -602,7 +619,7 @@ Functional Process Improvement
 Field Programmable Logic Array
 
 @item FPLMTS
-Future Public Land Mobile Telecommunications System (IN, Mobile Systems)
+Future Public Land Mobile Telecommunications System (IN, Mobile-Systems)
 
 @item FPM
 Fast Page Mode [DRAM] (RAM, DRAM)
@@ -709,11 +726,14 @@ File System Driver
 @item FSF
 Free Software Foundation (org., GNU)
 
+@item FSH
+File System Hierarchy (Linux, LSB)
+
 @item FSIP
 Full Scale InPut (FSOP)
 
 @item FSK
-Frequency Shift Keying (DFUE)
+Frequency Shift Keying (DFUe)
 
 @item FSM
 Finite State Machine (TTCN, ...)
@@ -826,7 +846,7 @@ Flow Update Notification [message] (LFAP)
 @item FUNI
 Frame User Network Interface
 
-FUEV          Fernmeldeanlagen-UEberwachungsVerordnung
+FUeV          Fernmeldeanlagen-UeberwachungsVerordnung
 
 @item FWH
 FirmWare Hub (BIOS, Intel)
