@@ -1,3 +1,8 @@
+@c -*-texinfo-*-
+@c This is part of the GNU edition of V.E.R.A.
+@c Copyright (C) 1993/2001 Oliver Heidelbach
+@c See the file vera.texi for copying conditions.
+@c 
 @c Syntax:
 @c ACRONYM
 @c Expansion[ (Reference)][, "Style"]
@@ -43,11 +48,14 @@ High Availability Subsystem (Bull)
 @item HAT
 Hashed Address Table
 
+@item HAVI
+Home Audio Video Interoperability (org., Grundig, Hitachi, Matsushita, Philips, Sharp, Sony, Thomson, Toshiba)
+
 @item HBA
 Host Bus Adapter (SCSI)
 
 @item HBCI
-HomeBanking Computer Interface (Internet, banking)
+HomeBanking Computer Interface Internet, banking, Germany, HBCI
 
 @item HBT
 Hetero Bipolar Transistor (IBM, IC)
@@ -79,6 +87,9 @@ High-Capacity Terrestrial Digital Service
 @item HD
 High Density
 
+@item HDAM
+Hierarchical Direct Access Method (DAM)
+
 @item HDB
 HoneyDanBer [standard] (Unix)
 
@@ -109,6 +120,9 @@ HDLC Distant Host
 @item HDI
 HOOPS Device Interface (VAGI)
 
+@item HDIT
+High Bandwidth Differential Interconnect Technology [bus] (VIA)
+
 @item HDL
 Hardware Description Language (ASIC)
 
@@ -119,7 +133,7 @@ High-level Data Link Control (ISO)
 Hardware Device Module (I2O)
 
 @item HDML
-Handheld Device Markup Language (Mobile Systems, HDTP)
+Handheld Device Markup Language (Mobile-Systems, HDTP)
 
 @item HDN
 Hochgeschwindigkeits-DatenNetz
@@ -137,11 +151,14 @@ High data / bit rate Digital Subscriber Line (BELLCORE, AT&T, DSL)
 High-level Data Specification Language
 
 @item HDTP
-Handheld Device Transport Protocol (Mobile Systems)
+Handheld Device Transport Protocol (Mobile-Systems)
 
 @item HDX
 Half DupleX
 
+@item HE
+HoehenEinheit [1HE = 19"]
+
 @item HEA
 Hyundai Electronics of America (manufacturer)
 
@@ -214,6 +231,9 @@ Hybrid Integrated Circuit
 @item HID
 Human Interface Device (MS)
 
+@item HIDAM
+Hierarchical Indexed Direct Access Method (DAM)
+
 @item HIFD
 HIgh capacity Floppy Disk (Sony, Fuji), "HiFD"
 
@@ -244,6 +264,9 @@ High Performance Peripheral Interface
 @item HIRD
 HURD of Interface Representing Depth (GNU, HURD)
 
+@item HISAM
+Hierarchical Indexed Sequential Acess Method (SAM)
+
 @item HISP
 HIgh SPeed channel connector (Cray, I/O)
 
@@ -257,7 +280,7 @@ High Level Language Application Programming Interface (IBM, API)
 Higher Layer Protocol Identifier
 
 @item HLR
-Home Location Register (LR, GSM, GPRS)
+Home Location Register (LR, GSM, GPRS, Mobile-Systems)
 
 @item HLS
 Hue, Luminance, Saturation (color system, DTP)
@@ -304,6 +327,9 @@ Host On Demand (IBM, HOD)
 @item HOL
 Head Of Line
 
+@item HOLAP
+Hybrid OnLine Analytical Processing (OLAP, DB)
+
 @item HOMERF
 Home Radio Frequency (WLAN), "HomeRF"
 
@@ -316,6 +342,9 @@ Homecast Open Protocol (WLAN, Alation Systems)
 @item HP
 Hewlett Packard (manufacturer)
 
+@item HPA
+High Performance Architecture (HP)
+
 @item HPBIDS
 Hewlett Packard Broadband Internet Delivery System (HP, Internet), "HP BIDS"
 
@@ -349,6 +378,9 @@ Hyper Page Mode
 @item HPMI
 ??? [Schnittstelle] (CAD), "HP-MI"
 
+@item HPNA
+???
+
 @item HPOFS
 High Performance Optical File System (IBM, OS/2, MOD)
 
@@ -401,7 +433,10 @@ Hierarchical Storage Controller
 High Speed Cable Data Services
 
 @item HSCSD
-High Speed Circuit Switched Data (GSM)
+High Speed Circuit Switched Data (GSM, Mobile-Systems)
+
+@item HSDRAM
+??? Random Access Memory (RAM, DRAM, IC)
 
 @item HSFS
 High Sierra File System
@@ -433,11 +468,14 @@ Hierarchical Storage Management
 @item HSM
 Hierarchisches SpeicherManagement
 
+@item HSMD
+High Speed Mobile Data HSCSD, Germany, E-Plus
+
 @item HSP
 [UUNet] HighSpeed Peering
 
 @item HSP
-Host Signal Processing (DFUE, WinModem)
+Host Signal Processing (DFUe, WinModem)
 
 @item HSRP
 Hot Standby Router Protocol (Cisco, IOS)
