@@ -1,3 +1,8 @@
+@c -*-texinfo-*-
+@c This is part of the GNU edition of V.E.R.A.
+@c Copyright (C) 1993/2001 Oliver Heidelbach
+@c See the file vera.texi for copying conditions.
+@c 
 @c Syntax:
 @c ACRONYM
 @c Expansion[ (Reference)][, "Style"]
@@ -74,13 +79,13 @@ Maintenance Analysis Procedure (IBM)
 Manufacturing Automation Protocol (General Motors)
 
 @item MAP
-Mobile Application Part (MSC, GSM)
+Mobile Application Part (MSC, GSM, Mobile-Systems)
 
 @item MAP27
 Mobile Access Protocol [for MPT 1327] (MPT 1327), "MAP 27"
 
 @item MAPASE
-Mobile Application Part - Application Service Elements (MAP, MSC, GSM), "MAP-ASE"
+Mobile Application Part - Application Service Elements (MAP, MSC, GSM, Mobile-Systems), "MAP-ASE"
 
 @item MAPI
 Messaging Application Program Interface (MS, WOSA, API)
@@ -250,6 +255,9 @@ Material Control System
 @item MCS
 Message Conversion System
 
+@item MCS
+Modulation and Coding Scheme (EGPRS, Mobile-Systems)
+
 @item MCS
 MultiCast Server
 
@@ -281,7 +289,7 @@ Mean Cell Transfer Delay (UNI, ATM)
 Management & Cascade Unit (Hub)
 
 @item MCU
-Micro Controller Unit (SIA)
+Micro Controller Unit (SIA, RL)
 
 @item MCU
 Multipoint Control Unit
@@ -307,6 +315,9 @@ Message Digest [algorithm] 4 (RFC 1320)
 @item MD5
 Message Digest [algorithm] 5 (RFC 1321)
 
+@item MDA
+Mail Delivery Agent
+
 @item MDA
 Medicated Digest Authentication (HTTP)
 
@@ -322,6 +333,15 @@ Micro Data Base System (DB)
 @item MDC
 Message conversion system directory Component (MCS)
 
+@item MDC
+Meta Data Coalition
+
+@item MDCT
+Modified Discrete Cosine Transformation
+
+@item MDDB
+MultiDimensional DataBase (DB)
+
 @item MDE
 ??? DatenErfassung
 
@@ -329,7 +349,7 @@ Message conversion system directory Component (MCS)
 Medium Dependent Interface (ethernet)
 
 @item MDI
-Mobile Data Initiative (org., GSM)
+Mobile Data Initiative (org., GSM, Mobile-Systems)
 
 @item MDI
 Multiple Document Interface (MS, Windows)
@@ -337,6 +357,9 @@ Multiple Document Interface (MS, Windows)
 @item MDI
 Multiplex Device Interface
 
+@item MDIS
+MetaData Interchange Specification
+
 @item MDK
 MODEM Developers Kit (MODEM, MS)
 
@@ -373,6 +396,9 @@ Mountain Daylight Time [-0600] (TZ, MST, USA)
 @item ME
 Mapping Entity
 
+@item ME
+Millennium Edition (MS, Windows)
+
 @item MEG
 Mega Evil Grin (slang, Usenet, IRC)
 
@@ -397,6 +423,9 @@ Manufacturing Execution System
 @item MES
 Menue-EntwicklungsSystem (Sinix, SNI)
 
+@item MES
+Minimum European Set (UTF, ISO 10646)
+
 @item MESA
 MetaEmailSearchAgent (WWW, Internet)
 
@@ -424,6 +453,9 @@ Memory Enhancement Technology (HP), "MEt"
 @item MET
 Middle European Time [+0100] (TZ, CET, METDST, MEZ)
 
+@item METAL
+Machine Evaluation and Translation Language (Siemens)
+
 @item METDST
 Middle European Time Daylight Saving Time [+0200] (TZ, MET, MEZ)
 
@@ -481,6 +513,9 @@ Message Format Service (IBM, IMS)
 @item MFS
 Mobile File Sync (IBM)
 
+@item MFS
+MOSIX File System (MOSIX, DFSA)
+
 @item MFT
 Master File Table (NTFS)
 
@@ -515,7 +550,7 @@ Multimedia and Hypermedia information coding Expert Group (JTC1, ISO)
 [columbia] Mobile Host Protocol
 
 @item MHP
-Multimedia Home Platform
+Multimedia Home Platform (ETSI)
 
 @item MHPCC
 Maui High Performance Computing Center (org., USA)
@@ -532,6 +567,9 @@ MIME [e-mail encapsulation of aggregate documents, such as] HTML (MIME, HTML, RF
 @item MI
 Management Interface
 
+@item MIA
+Missing In Action (DFUe, Usenet, IRC)
+
 @item MIAW
 Movie In A Window
 
@@ -676,6 +714,9 @@ Meta Language
 @item MLA
 Mail List Agent
 
+@item MLA
+Micro Lens Array
+
 @item MLC
 MultiLevel Cell (IC, PCMCIA, Flash, Intel)
 
@@ -722,7 +763,7 @@ Media Manager (Novell, Netware, SMS)
 Military Message (mil.)
 
 @item MM
-Mobile Management (RR, CM, GSM)
+Mobile Management (RR, CM, GSM, Mobile-Systems)
 
 @item MMA
 Microcomputer Managers Association (org., USA)
@@ -739,6 +780,9 @@ MIDI Machine Control
 @item MMC
 MultiMedia Commands (SAM)
 
+@item MMC
+MultiMediaCard
+
 @item MMCD
 MultiMedia Compact Disk (Sony, Philips, CD)
 
@@ -772,12 +816,18 @@ MultiMedia Human Interface Device
 @item MMHS
 Military Message Handling System (mil., MHS)
 
+@item MMI
+Mixed Mode Interpreter (JIT, IBM, Java)
+
 @item MMIO
 Memory Mapped I/O (I/O)
 
 @item MML
 Maker Markup Language (FrameMaker)
 
+@item MMP
+Multilink Multichasis PPP (PPP)
+
 @item MMPM2
 MultiMedia Presentation Manager /2 (IBM, OS/2), "MMPM/2"
 
@@ -841,6 +891,15 @@ MOdulator DEModulator
 @item MOE
 Measure of Effectiveness
 
+@item MOES
+Molekulare Optisch-Elektrische Schaltungstraeger
+
+@item MOESI
+Modified - Owner - Exclusive - Shared - Invalid (AMD)
+
+@item MOF
+Meta Object Facility
+
 @item MOLAP
 Multidimensional OnLine Analytical Processing (OLAP)
 
@@ -886,12 +945,18 @@ Major Open Systems Environment Standards
 @item MOSFET
 Metal Oxide Semiconductor Field Effect Transistor (IC, FET)
 
+@item MOSIX
+Multiprocessor ??? Operating System for unIX (Unix, Cluster)
+
 @item MOSP
 Microsoft Online Services Partnership (MSN)
 
 @item MOSPF
 Multicast [extensions to ] Open Shortest Path First [routing] (IP, OSPF, RFC 1584)
 
+@item MOST
+Media Orientated Systems Transport
+
 @item MOST
 Mobile Open Systems Technologies (UK, Uni Lancaster)
 
@@ -926,7 +991,7 @@ Multi Processor
 MultiProtocol
 
 @item MP3
-MPEG audio layer 3 (MPEG, audio)
+MPEG audio layer 3 (MPEG, audio, IIS, ISO)
 
 @item MPC
 MPOA Client (MPOA, ATM)
@@ -944,13 +1009,16 @@ MultiPlatform DiskArray
 Message Protocol Data Unit (PDU)
 
 @item MPEG
-Motion Picture Expert Group (org., ISO 11172-1, JTC1)
+Motion Picture Expert Group [old term] (MPEG)
+
+@item MPEG
+Moving Picture Expert Group (org., ISO 11172-1, JTC1)
 
 @item MPEXL
 ??? (HP), "MPE/XL"
 
 @item MPI
-Message Passing Interface (SMP)
+Message Passing Interface (SMP, Cluster)
 
 @item MPI
 Multiprocessor Interconnect Bus
@@ -977,7 +1045,7 @@ Multi-Protocol Over ATM (ATM)
 Multiple Purpose Operator Workstation
 
 @item MPP
-Massive Parallel Processor / Processing
+Massive Parallel Processor / Processing (MPP)
 
 @item MPP
 Message Posting Protocol (RFC 1204)
@@ -1037,7 +1105,7 @@ Multi Protocol Transport Services (IBM, MPTN)
 Multi Protocol Transport Services / 2 (IBM, OS/2), "MPTN/2" 
 
 @item MPU
-MicroProcessor Unit (SIA)
+MicroProcessor Unit (SIA, RL)
 
 @item MPU401
 MIDI Processing Unit 401 (Roland, MIDI), "MPU 401"
@@ -1100,7 +1168,10 @@ Mandatory Router Option [flag] (CATNIP)
 Multicommand Required Operational Capability
 
 @item MROM
-??? Read Only Memory
+??? Read Only Memory (ROM)
+
+@item MRP
+Material / Manufacturing Resource Palnning
 
 @item MRP
 Material Requirement Planning (PPS, CIM)
@@ -1133,7 +1204,7 @@ Meta Signaling (ATM, ???)
 MicroSoft (manufacturer, MS)
 
 @item MS
-Mobile Station (GSM)
+Mobile Station (GSM, Mobile-Systems)
 
 @item MSA
 Management Service Architecture
@@ -1151,7 +1222,7 @@ Most Significant Bit
 MicroSoft C
 
 @item MSC
-Mobile services Switching Center (PLMN, GSM, GPRS)
+Mobile services Switching Center (PLMN, GSM, GPRS, Mobile-Systems)
 
 @item MSCDEX
 MicroSoft Compact Disk EXtensions (CD)
@@ -1166,7 +1237,7 @@ Multiple Slots on Continuation Mechanism (DQDB)
 Mass Storage Control Protocol
 
 @item MSCS
-MicroSoft Cluster Server [Wolfpack] (MS)
+MicroSoft Cluster Server [Wolfpack] (MS, Cluster)
 
 @item MSD
 Most Significant Digit
@@ -1211,7 +1282,7 @@ Micro-Star International (manufacturer, Taiwan)
 MicroSoft Internet Explorer (MS, WWW, MSIE)
 
 @item MSISDN
-Mobile Station ISDN Number (PLMN, GSM), "MS-ISDN"
+Mobile Station ISDN Number (PLMN, GSM, Mobile-Systems), "MS-ISDN"
 
 @item MSIX
 Metered Services Information eXchange [protocol] (Internet, ISP)
@@ -1228,6 +1299,9 @@ Mirrored Server Link
 @item MSM
 Media Support Module (ODI)
 
+@item MSM
+Metal Semiconductor Metal (IC)
+
 @item MSMQ
 MicroSoft Message Queue [server] (MS)
 
@@ -1268,7 +1342,7 @@ Mobile Support Router (MHP)
 Model Specific Registers (Intel, Pentium)
 
 @item MSRN
-Mobile Station Roaming Number (MM, HLR, MS-ISDN, GSM)
+Mobile Station Roaming Number (MM, HLR, MS-ISDN, GSM, Mobile-Systems)
 
 @item MSRPC
 MicroSoft Remote Procedure Call (MS, DCOM), "MS-RPC"
@@ -1301,11 +1375,14 @@ Mannesmann Tally [gmbh] (manufacturer)
 Message Transfer / Type
 
 @item MT
-Mobile Termination (GSM)
+Mobile Termination (GSM, Mobile-Systems)
 
 @item MT
 Moluccas Time [+0830] (TZ)
 
+@item MTA
+Mail Transport Agent (SMTP)
+
 @item MTA
 Message Transfer Agent (MTS, OSI, X.400)
 
@@ -1349,7 +1426,7 @@ Memory Translator Hub (Intel)
 MIPS Technologies Inc. (manufacturer, SGI)
 
 @item MTP
-Message Transfer Part (ISDN, GSM)
+Message Transfer Part (ISDN, GSM, Mobile-Systems)
 
 @item MTRR
 Memory Type Range Register (CPU, Pentium Pro)
@@ -1429,11 +1506,14 @@ Master Upper Tester (ISO 9646-3, TTCN)
 @item MUTOS
 MultiUser-/multitasking Operating System (GDR, OS)
 
-MUEW          eW MonopolUEbertragungsWeg, "MueW"
+MUeW          eW MonopolUebertragungsWeg, "MueW"
 
 @item MUX
 MUltipleXer
 
+@item MVA
+Multi Vendor Architecture
+
 @item MVA
 Multidomain Vertical Alignment [technology] (LCD, Fujitsu)
 
